"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppUsageEvent = exports.AppUsageEventSource = void 0;
const domain_objects_1 = require("domain-objects");
/**
 * a source from which app usage events may be reported
 */
var AppUsageEventSource;
(function (AppUsageEventSource) {
    /**
     * events from the network the app is using
     *
     * for example
     * - loss of internet
     * - recovery of internet
     * - loading of data
     * - sending of a request
     */
    AppUsageEventSource["NETWORK"] = "NETWORK";
    /**
     * events from the device the app is running on
     *
     * for example
     * - device movement
     * - device orientation change
     */
    AppUsageEventSource["DEVICE"] = "DEVICE";
    /**
     * events from the software runtime the app is running in
     *
     * for example
     * - logs
     * - errors
     */
    AppUsageEventSource["RUNTIME"] = "RUNTIME";
    /**
     * events from the app screen
     *
     * for example
     * - loading
     * - visibility changes (focus, blur)
     * - resizing
     * - route changes
     */
    AppUsageEventSource["SCREEN"] = "SCREEN";
    /**
     * events from user activity in the app
     *
     * for example
     * - scrolling
     * - clicking
     * - typing
     */
    AppUsageEventSource["ACTIVITY"] = "ACTIVITY";
    /**
     * events from observations made during the app
     *
     * for example
     * - thirdparty analytics annotations (session recording urls, tracking ids, etc)
     * - components became visible
     */
    AppUsageEventSource["OBSERVATION"] = "OBSERVATION";
    /**
     * events from the domain logic of the app
     *
     * for example
     * - a conversion was recorded
     * - a learn-more button was pressed
     */
    AppUsageEventSource["DOMAIN"] = "DOMAIN";
})(AppUsageEventSource = exports.AppUsageEventSource || (exports.AppUsageEventSource = {}));
class AppUsageEvent extends domain_objects_1.DomainEvent {
}
exports.AppUsageEvent = AppUsageEvent;
//# sourceMappingURL=AppUsageEvent.js.map