"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppUsageEventProvider = void 0;
const react_1 = require("react");
const isCurrentlyServerside_1 = require("../utils/isCurrentlyServerside");
const autocaptureActivityEvents_1 = require("./capture/autocaptureActivityEvents");
const autocaptureDeviceEvents_1 = require("./capture/autocaptureDeviceEvents");
const autocaptureNetworkEvents_1 = require("./capture/autocaptureNetworkEvents");
const autocaptureRuntimeEvents_1 = require("./capture/autocaptureRuntimeEvents");
const autocaptureScreenEvents_1 = require("./capture/autocaptureScreenEvents");
const requeueTasksEmitToRemoteOnLoad_1 = require("./emit/asyncTask/requeueTasksEmitToRemoteOnLoad");
const getApiCredentials_1 = require("./emit/getApiCredentials");
const getApplicationOfSession_1 = require("./session/getApplicationOfSession");
const AppUsageEventProvider = ({ apiKey, apiHost, application, }) => {
    // set the api credentials
    (0, react_1.useEffect)(() => {
        if ((0, isCurrentlyServerside_1.isCurrentlyServerSide)())
            return; // do nothing if on serverside
        (0, getApiCredentials_1.setApiCredentials)({ apiKey, apiHost });
    }, [apiKey, apiHost]);
    // set the application
    (0, react_1.useEffect)(() => {
        if ((0, isCurrentlyServerside_1.isCurrentlyServerSide)())
            return; // do nothing if on serverside
        (0, getApplicationOfSession_1.setApplicationOfSession)(application);
    }, [application]);
    // instantiate the listeners and emitters
    (0, react_1.useEffect)(() => {
        if ((0, isCurrentlyServerside_1.isCurrentlyServerSide)())
            return; // do nothing if on serverside
        // instantiate the listeners
        (0, autocaptureNetworkEvents_1.autocaptureNetworkEvents)();
        (0, autocaptureDeviceEvents_1.autocaptureDeviceEvents)();
        (0, autocaptureRuntimeEvents_1.autocaptureRuntimeEvents)();
        (0, autocaptureScreenEvents_1.autocaptureScreenEvents)();
        (0, autocaptureActivityEvents_1.autocaptureActivityEvents)();
        // instantiate the emitters
        void (0, requeueTasksEmitToRemoteOnLoad_1.requeueTasksEmitToRemoteOnLoad)();
    }, []);
    // no component to display
    return null;
};
exports.AppUsageEventProvider = AppUsageEventProvider;
//# sourceMappingURL=AppUsageEventProvider.js.map