"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.autocaptureDeviceEvents = void 0;
const simple_in_memory_cache_1 = require("simple-in-memory-cache");
const with_simple_caching_1 = require("with-simple-caching");
const AppUsageEvent_1 = require("../../domain/AppUsageEvent");
const captureAppUsageEvent_1 = require("./captureAppUsageEvent");
/**
 * listen to and automatically capture device events
 *
 * note
 * - "with simple caching" to prevent duplicate mounting
 */
exports.autocaptureDeviceEvents = (0, with_simple_caching_1.withSimpleCaching)(() => {
    // device motion events; https://developer.mozilla.org/en-US/docs/Web/API/Window/devicemotion_event
    window.addEventListener('devicemotion', (event) => {
        var _a, _b, _c;
        return ((_a = event.acceleration) === null || _a === void 0 ? void 0 : _a.x) || ((_b = event.acceleration) === null || _b === void 0 ? void 0 : _b.y) || ((_c = event.acceleration) === null || _c === void 0 ? void 0 : _c.z)
            ? (0, captureAppUsageEvent_1.captureAppUsageEvent)({
                source: AppUsageEvent_1.AppUsageEventSource.DEVICE,
                type: 'device.motion',
                details: {
                    acceleration: event.acceleration,
                    accelerationIncludingGravity: event.accelerationIncludingGravity,
                },
            })
            : null;
    });
    // TODO: re-enable once we find a good way to debounce this input (and probably a usecase for it first)
    // // device compass events; https://developer.mozilla.org/en-US/docs/Web/API/Window/deviceorientation_event
    // addEventListener('deviceorientation', (event) =>
    //   event.alpha || event.beta || event.gamma
    //     ? captureAppUsageEvent({
    //         source: AppUsageEventSource.DEVICE,
    //         type: 'device.orientation',
    //         details: {
    //           alpha: event.alpha,
    //           beta: event.beta,
    //           gamma: event.gamma,
    //         } as never,
    //       })
    //     : null,
    // );
}, { cache: (0, simple_in_memory_cache_1.createCache)() });
//# sourceMappingURL=autocaptureDeviceEvents.js.map