"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.captureAppUsageEvent = void 0;
const uuid_1 = require("uuid");
const AppUsageEvent_1 = require("../../domain/AppUsageEvent");
const UnexpectedCodePathError_1 = require("../../utils/errors/UnexpectedCodePathError");
const appUsageEventsEmissionQueue_1 = require("../emit/appUsageEventsEmissionQueue");
const captureSessionLastUsedAt_1 = require("../session/captureSessionLastUsedAt");
const findOrCreateAppUsageSession_1 = require("../session/findOrCreateAppUsageSession");
const isAutocapturedSource = (source) => ![AppUsageEvent_1.AppUsageEventSource.OBSERVATION, AppUsageEvent_1.AppUsageEventSource.DOMAIN].includes(source);
/**
 * a simple method for capturing an app usage event
 */
const captureAppUsageEvent = ({ source, type, details, }) => __awaiter(void 0, void 0, void 0, function* () {
    // get the session uuid
    const { uuid: sessionUuid } = yield (0, findOrCreateAppUsageSession_1.findOrCreateAppUsageSession)();
    // validate that the type of the event is prefixed by the source, for our autocaptured sources
    const prefixExpected = `${source.toLowerCase()}.`;
    if (isAutocapturedSource(source) && !type.startsWith(prefixExpected)) {
        const error = new UnexpectedCodePathError_1.UnexpectedCodePathError('captureAppUsageEvent expects type to be prefixed with source', { type, prefixExpected });
        console.warn('AUE', 'could not capture app usage event', error);
        throw error;
    }
    // create the event
    const event = new AppUsageEvent_1.AppUsageEvent({
        uuid: (0, uuid_1.v4)(),
        occurredAtMse: new Date().getTime(),
        sessionUuid,
        route: window.location.href,
        source,
        type,
        details,
    });
    // queue it for emission
    appUsageEventsEmissionQueue_1.appUsageEventsEmissionQueue.push(event);
    // record session usage
    yield (0, captureSessionLastUsedAt_1.captureSessionLastUsedAt)({
        sessionUuid,
        lastUsedAtMse: new Date().getTime(),
    });
    // and return it
    return event;
});
exports.captureAppUsageEvent = captureAppUsageEvent;
//# sourceMappingURL=captureAppUsageEvent.js.map