"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.captureObservationEvent = void 0;
const simple_in_memory_queue_1 = require("simple-in-memory-queue");
const AppUsageEvent_1 = require("../../domain/AppUsageEvent");
const captureAppUsageEvent_1 = require("./captureAppUsageEvent");
const observationCaptureQueue = (0, simple_in_memory_queue_1.createQueueWithResilientRemoteConsumer)({
    consumer: ({ item }) => __awaiter(void 0, void 0, void 0, function* () {
        yield (0, captureAppUsageEvent_1.captureAppUsageEvent)({
            source: AppUsageEvent_1.AppUsageEventSource.OBSERVATION,
            type: item.type,
            details: item.details,
        });
    }),
    threshold: {
        concurrency: 1,
        retry: 5,
        pause: 10,
    },
    delay: {
        retry: 300,
    },
});
/**
 * enables programmatically capturing an observation that will be emitted as an app usage event
 *
 * usecases
 * - observe that a user has been given a particular experimental treatment
 * - observe that a user has been assigned some identifier from another analytics software
 * - etc
 *
 * note
 * - queues the requests so that even if session has not been defined yet, it will eventually succeed
 */
const captureObservationEvent = ({ type, details, }) => __awaiter(void 0, void 0, void 0, function* () {
    if (typeof window === 'undefined')
        return; // do nothing on serverside, since no installation-uuid available
    yield observationCaptureQueue.push({ type, details });
});
exports.captureObservationEvent = captureObservationEvent;
//# sourceMappingURL=captureObservationEvent.js.map