"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.calculateSequenceFromKeyEvents = void 0;
const simple_in_memory_queue_1 = require("simple-in-memory-queue");
const calculateSequenceFromKeyEvents = ({ events, }) => {
    // calculate the sequence
    const sequence = (0, simple_in_memory_queue_1.createQueue)({ order: simple_in_memory_queue_1.QueueOrder.LAST_IN_FIRST_OUT });
    for (const event of events) {
        // handle key down
        if (event.mode === 'down') {
            sequence.push(`d:${event.key}`);
            continue;
        }
        // handle key up equal to last key down
        const lastKeyDown = sequence.peek()[0];
        if (lastKeyDown === `d:${event.key}`) {
            sequence.pop(); // remove the `d:*` item from the queue
            sequence.push(event.key); // and add the key itself, without the modifier
            continue;
        }
        // handle key up not equal to last key down
        sequence.push(`u:${event.key}`);
    }
    // return the sequence
    return sequence.pop(0, sequence.length).reverse();
};
exports.calculateSequenceFromKeyEvents = calculateSequenceFromKeyEvents;
//# sourceMappingURL=calculateSequenceFromKeyEvents.js.map