"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.appUsageEventsEmissionQueue = exports.APP_USAGE_EVENTS_EMISSION_LOG_FIRST_ARG = void 0;
const simple_in_memory_queue_1 = require("simple-in-memory-queue");
const type_fns_1 = require("type-fns");
const AppUsageEvent_1 = require("../../domain/AppUsageEvent");
const queueTaskEmitToRemote_1 = require("./asyncTask/queueTaskEmitToRemote");
const base64EncodeCompressedPayload_1 = require("./compression/base64EncodeCompressedPayload");
const serializeAndCompressPayload_1 = require("./compression/serializeAndCompressPayload");
/**
 * define a standard first arg for console.logs emitted from our monitoring
 *
 * why?
 * - enables preventing infinite loop, since we also capture console.log events
 * - i.e., we can filter out the console.logs that have this prefix and not capture them
 */
exports.APP_USAGE_EVENTS_EMISSION_LOG_FIRST_ARG = 'AUE';
// create the queue w/ a batch consumer
exports.appUsageEventsEmissionQueue = (0, simple_in_memory_queue_1.createQueueWithBatchConsumer)({
    threshold: { milliseconds: 1000, size: 100 },
    consumer: ({ items: events }) => __awaiter(void 0, void 0, void 0, function* () {
        yield (0, queueTaskEmitToRemote_1.queueTaskEmitToRemote)({
            endpoint: '/capture/events',
            payload: (0, base64EncodeCompressedPayload_1.base64EncodeCompressedPayload)((0, serializeAndCompressPayload_1.serializeAndCompressPayload)(events)),
        });
    }),
});
// also, log out when events are added
exports.appUsageEventsEmissionQueue.on.push.subscribe({
    consumer: ({ event: { items } }) => [
        // skip logging noisy event sources
        AppUsageEvent_1.AppUsageEventSource.NETWORK,
        AppUsageEvent_1.AppUsageEventSource.ACTIVITY,
    ].includes(items[0].source)
        ? null
        : console.log(exports.APP_USAGE_EVENTS_EMISSION_LOG_FIRST_ARG, JSON.stringify((0, type_fns_1.pick)(items[0], ['source', 'type', 'details']))),
});
//# sourceMappingURL=appUsageEventsEmissionQueue.js.map