"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.daoTaskEmitToRemote = void 0;
const cross_sha256_1 = require("cross-sha256");
const domain_objects_1 = require("domain-objects");
const simple_async_tasks_1 = require("simple-async-tasks");
const simple_localstorage_cache_1 = require("simple-localstorage-cache");
const type_fns_1 = require("type-fns");
const uuid_1 = require("uuid");
const AsyncTaskEmitToRemote_1 = require("../../../domain/AsyncTaskEmitToRemote");
const castToSha256 = (str) => new cross_sha256_1.sha256().update(str).digest('hex');
const cache = (0, simple_localstorage_cache_1.createCache)({
    namespace: 'aue-tasks-emit',
    defaultSecondsUntilExpiration: null, // never expire, they'll be manually set to expire once fulfilled (in the upsert function)
});
const getCacheKey = ({ endpoint, payload, }) => castToSha256((0, domain_objects_1.serialize)({ endpoint, payload }));
const findByUnique = ({ endpoint, payload, }) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    const cacheKey = getCacheKey({ endpoint, payload });
    const cachedValue = yield cache.get(cacheKey);
    if (!cachedValue)
        return null;
    return (_a = (0, domain_objects_1.deserialize)(cachedValue, { with: [AsyncTaskEmitToRemote_1.AsyncTaskEmitToRemote] })) !== null && _a !== void 0 ? _a : null;
});
/**
 * method for finding all tasks matching included statuses
 *
 * note:
 * - current implementation does not index by status, since the total number of keys should always be small
 */
const findAllByStatus = ({ status, }) => __awaiter(void 0, void 0, void 0, function* () {
    const keysAll = yield cache.keys();
    const tasksAll = (yield Promise.all(keysAll.map((key) => cache.get(key))))
        .filter(type_fns_1.isPresent)
        .map((taskJSON) => (0, domain_objects_1.deserialize)(taskJSON, {
        with: [AsyncTaskEmitToRemote_1.AsyncTaskEmitToRemote],
    }));
    const tasksMatching = tasksAll.filter((task) => status.includes(task.status));
    return tasksMatching;
});
const upsert = ({ task }) => __awaiter(void 0, void 0, void 0, function* () {
    // find or create the metadata for this object by unique key
    const foundObject = yield findByUnique(task);
    const metadata = (() => {
        if (foundObject)
            return { uuid: foundObject.uuid };
        return { uuid: (0, uuid_1.v4)() };
    })();
    // upsert the object
    const cacheKey = getCacheKey(task);
    const taskWithMetadata = new AsyncTaskEmitToRemote_1.AsyncTaskEmitToRemote(Object.assign(Object.assign(Object.assign({}, task), metadata), { updatedAt: new Date().toISOString() }));
    yield cache.set(cacheKey, (0, domain_objects_1.serialize)(taskWithMetadata), {
        secondsUntilExpiration: taskWithMetadata.status === simple_async_tasks_1.AsyncTaskStatus.FULFILLED ? 15 : 0, // if fulfilled, set to remove it from cache in 60 seconds
    });
    return taskWithMetadata;
});
exports.daoTaskEmitToRemote = {
    findAllByStatus,
    findByUnique,
    upsert,
};
//# sourceMappingURL=daoTaskEmitToRemote.js.map