"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const domain_objects_1 = require("domain-objects");
const simple_async_tasks_1 = require("simple-async-tasks");
const uuid_1 = require("uuid");
const AsyncTaskEmitToRemote_1 = require("../../../domain/AsyncTaskEmitToRemote");
const daoTaskEmitToRemote_1 = require("./daoTaskEmitToRemote");
// mock out localstorage since we're basing our dao based on a localstorage cache
const mockStore = {};
const mockGetItem = jest.fn((key) => mockStore[key]);
const mockSetItem = jest.fn((key, value) => (mockStore[key] = value));
const mockRemoveItem = jest.fn((key) => {
    delete mockStore[key];
});
Object.defineProperty(window, 'localStorage', {
    value: {
        getItem: mockGetItem,
        setItem: mockSetItem,
        removeItem: mockRemoveItem,
    },
});
describe('daoTaskEmitToRemote', () => {
    it('should be able to upsert', () => __awaiter(void 0, void 0, void 0, function* () {
        const task = new AsyncTaskEmitToRemote_1.AsyncTaskEmitToRemote({
            status: simple_async_tasks_1.AsyncTaskStatus.QUEUED,
            endpoint: '/session',
            bytes: 7,
            payload: (0, uuid_1.v4)(),
        });
        yield daoTaskEmitToRemote_1.daoTaskEmitToRemote.upsert({ task });
    }));
    it('should be able to find by unique', () => __awaiter(void 0, void 0, void 0, function* () {
        const task = new AsyncTaskEmitToRemote_1.AsyncTaskEmitToRemote({
            status: simple_async_tasks_1.AsyncTaskStatus.QUEUED,
            endpoint: '/session',
            bytes: 7,
            payload: (0, uuid_1.v4)(),
        });
        yield daoTaskEmitToRemote_1.daoTaskEmitToRemote.upsert({ task });
        const taskFound = yield daoTaskEmitToRemote_1.daoTaskEmitToRemote.findByUnique(task);
        expect((0, domain_objects_1.omitMetadataValues)(taskFound)).toEqual((0, domain_objects_1.omitMetadataValues)(task));
    }));
});
//# sourceMappingURL=daoTaskEmitToRemote.test.js.map