"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.queueTaskEmitToRemote = exports.asyncTaskEmitToRemoteQueue = void 0;
const simple_async_tasks_1 = require("simple-async-tasks");
const simple_in_memory_queue_1 = require("simple-in-memory-queue");
const AsyncTaskEmitToRemote_1 = require("../../../domain/AsyncTaskEmitToRemote");
const daoTaskEmitToRemote_1 = require("./daoTaskEmitToRemote");
const executeTaskEmitToRemote_1 = require("./executeTaskEmitToRemote");
exports.asyncTaskEmitToRemoteQueue = (0, simple_in_memory_queue_1.createQueueWithResilientRemoteConsumer)({
    consumer: ({ item }) => __awaiter(void 0, void 0, void 0, function* () {
        yield (0, executeTaskEmitToRemote_1.executeTaskEmitToRemote)({
            task: item,
        });
    }),
    threshold: {
        concurrency: 1,
        retry: 3,
        pause: 5, // pause all consumption if 5 tasks in a row fail
    },
    delay: {
        retry: 100,
        visibility: 100,
    },
    on: {
        failureAttempt: ({ item, attempt, error }) => console.warn('🤔 failed attempting to emit to remote', {
            item,
            attempt,
            error,
        }),
        failurePermanent: ({ item, error }) => console.warn('😞 failed permanently to emit to remote', {
            item,
            error,
        }),
        pause: ({ failures }) => console.warn('🛑 failed too many tasks in a row, pausing emit to remote', {
            failures,
        }),
    },
});
exports.queueTaskEmitToRemote = (0, simple_async_tasks_1.withAsyncTaskExecutionLifecycleQueue)({
    dao: daoTaskEmitToRemote_1.daoTaskEmitToRemote,
    queue: exports.asyncTaskEmitToRemoteQueue,
    getNew: ({ endpoint, payload }) => new AsyncTaskEmitToRemote_1.AsyncTaskEmitToRemote({
        status: simple_async_tasks_1.AsyncTaskStatus.QUEUED,
        endpoint,
        bytes: new Blob([payload]).size,
        payload,
    }),
});
//# sourceMappingURL=queueTaskEmitToRemote.js.map