"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const pako_1 = __importDefault(require("pako"));
const uuid_1 = require("uuid");
const AppUsageEvent_1 = require("../../../domain/AppUsageEvent");
const base64DecodeCompressedPayload_1 = require("./base64DecodeCompressedPayload");
const base64EncodeCompressedPayload_1 = require("./base64EncodeCompressedPayload");
const serializeAndCompressPayload_1 = require("./serializeAndCompressPayload");
const exampleEvents = [
    new AppUsageEvent_1.AppUsageEvent({
        uuid: (0, uuid_1.v4)(),
        occurredAtMse: new Date().getTime(),
        sessionUuid: (0, uuid_1.v4)(),
        route: window.location.href,
        source: AppUsageEvent_1.AppUsageEventSource.ACTIVITY,
        type: 'test',
        details: null,
    }),
    new AppUsageEvent_1.AppUsageEvent({
        uuid: (0, uuid_1.v4)(),
        occurredAtMse: new Date().getTime(),
        sessionUuid: (0, uuid_1.v4)(),
        route: window.location.href,
        source: AppUsageEvent_1.AppUsageEventSource.ACTIVITY,
        type: 'test',
        details: { some: 'thing' },
    }),
];
describe('base64EncodeCompressedPayload', () => {
    it('should be able to encode the compressed events', () => {
        const compressed = (0, serializeAndCompressPayload_1.serializeAndCompressPayload)(exampleEvents);
        const encoded = (0, base64EncodeCompressedPayload_1.base64EncodeCompressedPayload)(compressed);
        console.log(encoded);
    });
    it('should produce equivalent values when encoded and decoded roundtrip', () => {
        const compressed = (0, serializeAndCompressPayload_1.serializeAndCompressPayload)(exampleEvents);
        const encoded = (0, base64EncodeCompressedPayload_1.base64EncodeCompressedPayload)(compressed);
        const decoded = (0, base64DecodeCompressedPayload_1.base64DecodeCompressedPayload)(encoded);
        expect(decoded).toEqual(compressed);
        // bonus: can decode back to original value
        const decompressed = pako_1.default.inflate(decoded, { to: 'string' });
        expect(decompressed).toEqual(JSON.stringify(exampleEvents));
    });
});
//# sourceMappingURL=base64EncodeCompressedPayload.test.js.map