"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const object_sizeof_1 = __importDefault(require("object-sizeof"));
const pako_1 = __importDefault(require("pako"));
const uuid_1 = require("uuid");
const AppUsageEvent_1 = require("../../../domain/AppUsageEvent");
const serializeAndCompressPayload_1 = require("./serializeAndCompressPayload");
const exampleEvents = [
    new AppUsageEvent_1.AppUsageEvent({
        uuid: (0, uuid_1.v4)(),
        occurredAtMse: new Date().getTime(),
        sessionUuid: (0, uuid_1.v4)(),
        route: window.location.href,
        source: AppUsageEvent_1.AppUsageEventSource.ACTIVITY,
        type: 'test',
        details: null,
    }),
    new AppUsageEvent_1.AppUsageEvent({
        uuid: (0, uuid_1.v4)(),
        occurredAtMse: new Date().getTime(),
        sessionUuid: (0, uuid_1.v4)(),
        route: window.location.href,
        source: AppUsageEvent_1.AppUsageEventSource.ACTIVITY,
        type: 'test',
        details: { some: 'thing' },
    }),
];
describe('serializeAndCompressAppUsageEvents', () => {
    it('should be able to serialize and compress events', () => {
        const compressed = (0, serializeAndCompressPayload_1.serializeAndCompressPayload)(exampleEvents);
        expect(compressed).toBeInstanceOf(Uint8Array);
    });
    it('should produce equivalent values when compressed and decompressed roundtrip', () => {
        const compressed = (0, serializeAndCompressPayload_1.serializeAndCompressPayload)(exampleEvents);
        const decompressed = pako_1.default.inflate(compressed, { to: 'string' });
        expect(decompressed).toEqual(JSON.stringify(exampleEvents));
    });
    it('should save size after compression', () => {
        const originalSize = (0, object_sizeof_1.default)([
            ...exampleEvents,
            ...exampleEvents,
            ...exampleEvents,
            ...exampleEvents,
            ...exampleEvents,
            ...exampleEvents,
            ...exampleEvents,
            ...exampleEvents,
            ...exampleEvents,
        ]);
        const compressedSize = (0, object_sizeof_1.default)((0, serializeAndCompressPayload_1.serializeAndCompressPayload)(exampleEvents));
        console.log({ originalSize, compressedSize });
        expect(originalSize).toBeGreaterThan(compressedSize);
    });
});
//# sourceMappingURL=serializeAndCompressPayload.test.js.map