"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.findOrCreateInstallationUuid = void 0;
const simple_in_memory_cache_1 = require("simple-in-memory-cache");
const with_simple_caching_1 = require("with-simple-caching");
const deps_1 = require("../../deps");
const INSTALLATION_STORAGE_KEY = 'app-usage-installation';
/**
 * finds or creates the installation uuid for this device
 *
 * note
 * - installation uuids are "permanent" uuids assigned to the particular install of our app
 * - in the browser environment,
 *   - an "install" is considered as the first time that the app is loaded (i.e., local storage does not have the installation uuid)
 *   - an "uninstall" is considered as when the user clears their browsers cache (i.e., wipes local storage)
 * - therefore,
 *   - we simply find or create the uuid in localstorage
 */
exports.findOrCreateInstallationUuid = (0, with_simple_caching_1.withSimpleCaching)(() => __awaiter(void 0, void 0, void 0, function* () {
    const found = localStorage.getItem(INSTALLATION_STORAGE_KEY);
    if (found)
        return found;
    const created = (0, deps_1.uuid)();
    localStorage.setItem(INSTALLATION_STORAGE_KEY, created);
    return created;
}), {
    cache: (0, simple_in_memory_cache_1.createCache)(),
});
//# sourceMappingURL=findOrCreateInstallationUuid.js.map